Index: src/wp-admin/credits.php
===================================================================
--- src/wp-admin/credits.php	(revision 49090)
+++ src/wp-admin/credits.php	(working copy)
@@ -4,6 +4,7 @@
  *
  * @package WordPress
  * @subpackage Administration
+ * @var string $title
  */
 
 /** WordPress Administration Bootstrap */
Index: src/wp-admin/edit-comments.php
===================================================================
--- src/wp-admin/edit-comments.php	(revision 49090)
+++ src/wp-admin/edit-comments.php	(working copy)
@@ -4,10 +4,15 @@
  *
  * @package WordPress
  * @subpackage Administration
+ * 
+ * @global wpdb   $wpdb                   WordPress database abstraction object.
+ * @global int $post_id
  */
 
 /** WordPress Administration Bootstrap */
 require_once __DIR__ . '/admin.php';
+global $wpdb , $post_id;
+
 if ( ! current_user_can( 'edit_posts' ) ) {
 	wp_die(
 		'<h1>' . __( 'You need a higher level of permission.' ) . '</h1>' .
@@ -135,6 +140,8 @@
 wp_enqueue_script( 'admin-comments' );
 enqueue_comment_hotkeys_js();
 
+$post_id = isset( $_REQUEST['p'] ) ? absint( $_REQUEST['p'] ) : 0;
+
 if ( $post_id ) {
 	$comments_count      = wp_count_comments( $post_id );
 	$draft_or_post_title = wp_html_excerpt( _draft_or_post_title( $post_id ), 50, '&hellip;' );
Index: src/wp-admin/edit.php
===================================================================
--- src/wp-admin/edit.php	(revision 49090)
+++ src/wp-admin/edit.php	(working copy)
@@ -4,11 +4,14 @@
  *
  * @package WordPress
  * @subpackage Administration
+ * @global     string    $typenow
  */
 
 /** WordPress Administration Bootstrap */
 require_once __DIR__ . '/admin.php';
 
+global $typenow;
+
 if ( ! $typenow ) {
 	wp_die( __( 'Invalid post type.' ) );
 }
@@ -26,8 +29,9 @@
 /**
  * @global string       $post_type
  * @global WP_Post_Type $post_type_object
+ * @global wpdb         $wpdb                   WordPress database abstraction object.
  */
-global $post_type, $post_type_object;
+global $wpdb, $post_type, $post_type_object;
 
 $post_type        = $typenow;
 $post_type_object = get_post_type_object( $post_type );
Index: src/wp-admin/includes/ajax-actions.php
===================================================================
--- src/wp-admin/includes/ajax-actions.php	(revision 49090)
+++ src/wp-admin/includes/ajax-actions.php	(working copy)
@@ -426,6 +426,7 @@
  *
  * @param int $comment_id
  * @param int $delta
+ * @var array $query_vars See {@link WP::parse_request()}.
  */
 function _wp_ajax_delete_comment_response( $comment_id, $delta = -1 ) {
 	$total    = isset( $_POST['_total'] ) ? (int) $_POST['_total'] : 0;
@@ -3614,6 +3615,7 @@
  * @global WP_Embed   $wp_embed   Embed API instance.
  * @global WP_Scripts $wp_scripts
  * @global int        $content_width
+ * @var    array      $matches
  */
 function wp_ajax_parse_embed() {
 	global $post, $wp_embed, $content_width;
Index: src/wp-admin/install.php
===================================================================
--- src/wp-admin/install.php	(revision 49090)
+++ src/wp-admin/install.php	(working copy)
@@ -222,11 +222,12 @@
 }
 
 /**
+ * @global wpdb   $wpdb                   WordPress database abstraction object.
  * @global string $wp_version             The WordPress version string.
  * @global string $required_php_version   The required PHP version string.
  * @global string $required_mysql_version The required MySQL version string.
  */
-global $wp_version, $required_php_version, $required_mysql_version;
+global $wp_version, $wpdb, $required_php_version, $required_mysql_version;
 
 $php_version   = phpversion();
 $mysql_version = $wpdb->db_version();

Index: src/wp-admin/includes/class-core-upgrader.php
===================================================================
--- src/wp-admin/includes/class-core-upgrader.php	(revision 49090)
+++ src/wp-admin/includes/class-core-upgrader.php	(working copy)
@@ -45,6 +45,7 @@
 	 *
 	 * @global WP_Filesystem_Base $wp_filesystem                WordPress filesystem subclass.
 	 * @global callable           $_wp_filesystem_direct_method
+	 * @global string             $wp_version                   The WordPress version string.
 	 *
 	 * @param object $current Response object for whether WordPress is current.
 	 * @param array  $args {
@@ -60,7 +61,7 @@
 	 * @return string|false|WP_Error New WordPress version on success, false or WP_Error on failure.
 	 */
 	public function upgrade( $current, $args = array() ) {
-		global $wp_filesystem;
+	    global $wp_filesystem, $wp_version;
 
 		require ABSPATH . WPINC . '/version.php'; // $wp_version;
 
@@ -267,10 +268,13 @@
 	 *
 	 * @since 3.7.0
 	 *
 	 * @param string $offered_ver The offered version, of the format x.y.z.
 	 * @return bool True if we should update to the offered version, otherwise false.
 	 */
 	public static function should_update_to_version( $offered_ver ) {
+	    global $wp_version;
+	    
 		require ABSPATH . WPINC . '/version.php'; // $wp_version; // x.y.z
 
 		$current_branch = implode( '.', array_slice( preg_split( '/[.-]/', $wp_version ), 0, 2 ) ); // x.y
@@ -267,10 +268,13 @@
 	 * @since 3.7.0
 	 *
-	 * @param string $offered_ver The offered version, of the format x.y.z.
-	 * @return bool True if we should update to the offered version, otherwise false.
+	 * @global string  $wp_version       The WordPress version string.
+	 * @param  string  $offered_ver      The offered version, of the format x.y.z.
+	 * @return bool    True              if we should update to the offered version, otherwise false.
 	 */
 	public static function should_update_to_version( $offered_ver ) {